%define module  mpi4py
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

Summary:       MPI for Python
Name:          python-%{module}
Version:       3.1.5
Release:       %mkrel 2
License:       Public Domain
Group:         Development/Python
Url:           https://github.com/mpi4py/mpi4py
Source0:       https://github.com/mpi4py/mpi4py/archive/refs/tags/%{version}.tar.gz
Patch0:        0001-add-debug-symbols.patch
BuildRequires: openmpi
BuildRequires: pkgconfig(ompi)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(python3)
BuildRequires: python3dist(cython)

#(eatdirt) openmpi does no longer support 32 bits
ExcludeArch:   %{ix86}
ExcludeArch:    %{arm32}

%description
MPI for Python provides bindings of the Message Passing Interface
(MPI) standard for the Python programming language, allowing any
Python program to exploit multiple processors.

This package is constructed on top of the MPI-1/2 specifications and
provides an object oriented interface which closely follows MPI-2 C++
bindings. It supports point-to-point (sends, receives) and collective
(broadcasts, scatters, gathers) communications of any picklable Python
object, as well as optimized communications of Python object exposing
the single-segment buffer interface (NumPy arrays, builtin
bytes/string/array objects).

%package doc
Summary:    Documentation for mpi4py
Group:      Development/Python
BuildArch:  noarch

%description doc
This package contains documentation for MPI for Python.

%package -n python3-%{module}
Summary:    Python 3 bindings of the Message Passing Interface (MPI)
Group:      Development/Python
Requires:   openmpi
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
MPI for Python provides bindings of the Message Passing Interface
(MPI) standard for the Python programming language, allowing any
Python 3 program to exploit multiple processors.

This package is constructed on top of the MPI-1/2 specifications and
provides an object oriented interface which closely follows MPI-2 C++
bindings. It supports point-to-point (sends, receives) and collective
(broadcasts, scatters, gathers) communications of any picklable Python
object, as well as optimized communications of Python object exposing
the single-segment buffer interface (NumPy arrays, builtin
bytes/string/array objects).

%package -n python3-%{module}-devel
Summary:    mpi4py headers
Group:      Development/Python
Requires:   python3-%{module} = %{version}-%{release}

%description -n python3-%{module}-devel
This package contains header files needed to develop modules in C or
Fortran that can interact with mpi4py.

%prep
%setup -q -n %{module}-%{version}
# delete docs/source
# this is just needed to generate docs/*
rm -r docs/source

# work around "wrong-file-end-of-line-encoding"
for file in $(find | grep runtests.bat); do
    sed -i 's/\r//' $file
done

%build
export CFLAGS="%{optflags} -Wno-error=format-security"
%pyproject_wheel

%install
%pyproject_install
rm -f %{buildroot}%{python3_sitearch}/mpi4py/mpi.cfg

%files doc
%doc test/ demo/ docs/

%files -n python3-%{module}
%{python3_sitearch}/%{module}*
%exclude %{python3_sitearch}/%{module}/include/

%files -n python3-%{module}-devel
%{python3_sitearch}/%{module}/include/


%changelog
* Fri Feb 23 2024 eatdirt <eatdirt> 3.1.5-2.mga10
+ Revision: 2043746
- Rebuild for new openmpi, exclude 32bits arches

* Wed Dec 20 2023 papoteur <papoteur> 3.1.5-1.mga10
+ Revision: 2020011
- add generation of debug symbols
- new 3.1.5

* Wed Jun 07 2023 eatdirt <eatdirt> 3.1.4-1.mga9
+ Revision: 1961172
- Update to bug fix release 3.1.4

* Thu Mar 31 2022 umeabot <umeabot> 3.1.3-2.mga9
+ Revision: 1837255
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 3.1.3-1.mga9
+ Revision: 1782938
- 3.1.3
- new URL
- Rebuild for python-3.10

* Sat Mar 20 2021 daviddavid <daviddavid> 3.0.3-2.mga9
+ Revision: 1705806
- rebuild for python 3.9

* Sat Mar 21 2020 eatdirt <eatdirt> 3.0.3-1.mga8
+ Revision: 1558459
- Upgrade to version 3.0.3

* Sun Feb 16 2020 umeabot <umeabot> 3.0.1-4.mga8
+ Revision: 1534819
- Mageia 8 Mass Rebuild

* Mon Oct 07 2019 daviddavid <daviddavid> 3.0.1-3.mga8
+ Revision: 1450072
- add missing dependency on openmpi

* Mon Sep 16 2019 daviddavid <daviddavid> 3.0.1-2.mga8
+ Revision: 1442337
- rebuild for python3.8
- drop python2 support

* Fri Mar 08 2019 eatdirt <eatdirt> 3.0.1-1.mga7
+ Revision: 1372932
- Upgrade to version 3.0.1

* Tue Jan 08 2019 tv <tv> 3.0.0-3.mga7
+ Revision: 1352232
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 3.0.0-2.mga7
+ Revision: 1300529
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 eatdirt <eatdirt> 3.0.0-1.mga7
+ Revision: 1246663
- Upgrade to version 3.0.0

* Fri May 18 2018 eatdirt <eatdirt> 1.3.1-16.mga7
+ Revision: 1230346
- Rebuild for new openmpi

* Sat May 05 2018 daviddavid <daviddavid> 1.3.1-15.mga7
+ Revision: 1226313
- rename python-mpi4py to python2-mpi4py
- rename python-mpi4py-devel to python2-mpi4py-devel

* Mon Oct 09 2017 eatdirt <eatdirt> 1.3.1-14.mga7
+ Revision: 1170571
- Rebuild for new openmpi

* Sat Aug 05 2017 pterjan <pterjan> 1.3.1-13.mga7
+ Revision: 1135504
- Rebuild for python 3.6

* Fri Dec 02 2016 tmb <tmb> 1.3.1-12.mga6
+ Revision: 1071632
- rebuild for new openmpi

* Tue Feb 16 2016 umeabot <umeabot> 1.3.1-11.mga6
+ Revision: 962243
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 tv <tv> 1.3.1-10.mga6
+ Revision: 887582
- rebuild for python 3.5
- rebuild for python 3.5

* Wed Sep 30 2015 joequant <joequant> 1.3.1-8.mga6
+ Revision: 885242
- fix mpi

* Wed Oct 15 2014 umeabot <umeabot> 1.3.1-8.mga5
+ Revision: 744656
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.3.1-7.mga5
+ Revision: 729121
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.3.1-6.mga5
+ Revision: 688161
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.3.1-5.mga5
+ Revision: 628817
- Rebuild for new Python

* Sun Dec 01 2013 philippem <philippem> 1.3.1-4.mga4
+ Revision: 554555
- add Python 3, split doc in sub package

* Tue Oct 22 2013 umeabot <umeabot> 1.3.1-3.mga4
+ Revision: 543732
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.3.1-2.mga4
+ Revision: 498939
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Aug 27 2013 philippem <philippem> 1.3.1-1.mga4
+ Revision: 472330
- update to 1.3.1
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jun 14 2012 eatdirt <eatdirt> 1.3-2.mga3
+ Revision: 260541
- Rebuild for new openmpi-1.6

* Thu Jun 14 2012 fwang <fwang> 1.3-1.mga3
+ Revision: 260447
- update file list
- update file list
+ lebedov <lebedov>
- Update to 1.3.

* Fri Jan 13 2012 eatdirt <eatdirt> 1.2.2-2.mga2
+ Revision: 195649
- Rebuild against openmpi-1.4.4

* Tue Sep 20 2011 lebedov <lebedov> 1.2.2-1.mga2
+ Revision: 146091
- imported package python-mpi4py

